VideoPlayerDataSource class
Constructors
-
VideoPlayerDataSource(VideoPlayerDataSourceType type, String url, {String? package, VideoFormat? videoFormat, VideoPlayerOptions? videoPlayerOptions, Future<ClosedCaptionFile>? closedCaptionFile})
-
-
VideoPlayerDataSource.asset(String url, {String? package, VideoPlayerOptions? videoPlayerOptions, Future<ClosedCaptionFile>? closedCaptionFile})
-
-
VideoPlayerDataSource.file(String url, {VideoPlayerOptions? videoPlayerOptions, Future<ClosedCaptionFile>? closedCaptionFile})
-
-
VideoPlayerDataSource.network(String url, {VideoFormat? videoFormat, VideoPlayerOptions? videoPlayerOptions, Future<ClosedCaptionFile>? closedCaptionFile})
-
Properties
-
closedCaptionFile
↔ Future<ClosedCaptionFile>?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
Custom headers for player
final
-
package
→ String?
-
Only set for asset videos. The package that the asset was loaded from.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
→ VideoPlayerDataSourceType
-
Type of source of video
final
-
url
→ String
-
Url of the video
final
-
videoFormat
→ VideoFormat?
-
Android only. Will override the platform's generic file format
detection with whatever is set here.
final
-
videoPlayerOptions
→ VideoPlayerOptions?
-
Provide additional configuration options (optional). Like setting the audio mode to mix
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited